package com.ruoyi.ems.record.service;

import java.util.List;

import com.ruoyi.ems.record.domain.EmsRecordDnbInstant;

/**
 * 电实时数据Service接口
 *
 * @author Yinq
 * @date 2024-05-11
 */
public interface IEmsRecordDnbInstantService {
    /**
     * 查询电实时数据
     *
     * @param objId 电实时数据主键
     * @return 电实时数据
     */
    public EmsRecordDnbInstant selectEmsRecordDnbInstantByObjId(Long objId);

    /**
     * 查询电实时数据列表
     *
     * @param emsRecordDnbInstant 电实时数据
     * @return 电实时数据集合
     */
    public List<EmsRecordDnbInstant> selectEmsRecordDnbInstantList(EmsRecordDnbInstant emsRecordDnbInstant);

    /**
     * 新增电实时数据
     *
     * @param emsRecordDnbInstant 电实时数据
     * @return 结果
     */
    public int insertEmsRecordDnbInstant(EmsRecordDnbInstant emsRecordDnbInstant);

    /**
     * 修改电实时数据
     *
     * @param emsRecordDnbInstant 电实时数据
     * @return 结果
     */
    public int updateEmsRecordDnbInstant(EmsRecordDnbInstant emsRecordDnbInstant);

    /**
     * 批量删除电实时数据
     *
     * @param objIds 需要删除的电实时数据主键集合
     * @return 结果
     */
    public int deleteEmsRecordDnbInstantByObjIds(Long[] objIds);

    /**
     * 删除电实时数据信息
     *
     * @param objId 电实时数据主键
     * @return 结果
     */
    public int deleteEmsRecordDnbInstantByObjId(Long objId);

    /**
     * 查询电实时数据
     * @param emsRecordDnbInstant
     * @return
     */
    List<EmsRecordDnbInstant> selectDnbInstantList(EmsRecordDnbInstant emsRecordDnbInstant);
}
