package com.ruoyi.ems.record.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ems.record.domain.EmsRecordDnbInstant;
import com.ruoyi.ems.record.service.IEmsRecordDnbInstantService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 电实时数据Controller
 *
 * @author Yinq
 * @date 2024-05-11
 */
@RestController
@RequestMapping("/ems/record/recordDnbInstant")
public class EmsRecordDnbInstantController extends BaseController {
    @Autowired
    private IEmsRecordDnbInstantService emsRecordDnbInstantService;

    /**
     * 查询电实时数据列表
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordDnbInstant:list')")
    @GetMapping("/list")
    public TableDataInfo list(EmsRecordDnbInstant emsRecordDnbInstant) {
        startPage();
        List<EmsRecordDnbInstant> list = emsRecordDnbInstantService.selectEmsRecordDnbInstantList(emsRecordDnbInstant);
        return getDataTable(list);
    }

    /**
     * 查询电实时数据
     * @param emsRecordDnbInstant
     * @return
     */
    @GetMapping("/dnbInstantList")
    public AjaxResult dnbInstantList(EmsRecordDnbInstant emsRecordDnbInstant) {
        List<EmsRecordDnbInstant> list = emsRecordDnbInstantService.selectDnbInstantList(emsRecordDnbInstant);
        return success(list);
    }

    /**
     * 导出电实时数据列表
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordDnbInstant:export')")
    @Log(title = "电实时数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EmsRecordDnbInstant emsRecordDnbInstant) {
        List<EmsRecordDnbInstant> list = emsRecordDnbInstantService.selectEmsRecordDnbInstantList(emsRecordDnbInstant);
        ExcelUtil<EmsRecordDnbInstant> util = new ExcelUtil<EmsRecordDnbInstant>(EmsRecordDnbInstant.class);
        util.exportExcel(response, list, "电实时数据数据");
    }

    /**
     * 获取电实时数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordDnbInstant:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(emsRecordDnbInstantService.selectEmsRecordDnbInstantByObjId(objId));
    }

    /**
     * 新增电实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordDnbInstant:add')")
    @Log(title = "电实时数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EmsRecordDnbInstant emsRecordDnbInstant) {
        emsRecordDnbInstant.setCreateBy(getUsername());
        return toAjax(emsRecordDnbInstantService.insertEmsRecordDnbInstant(emsRecordDnbInstant));
    }

    /**
     * 修改电实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordDnbInstant:edit')")
    @Log(title = "电实时数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EmsRecordDnbInstant emsRecordDnbInstant) {
        emsRecordDnbInstant.setUpdateBy(getUsername());
        return toAjax(emsRecordDnbInstantService.updateEmsRecordDnbInstant(emsRecordDnbInstant));
    }

    /**
     * 删除电实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordDnbInstant:remove')")
    @Log(title = "电实时数据", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(emsRecordDnbInstantService.deleteEmsRecordDnbInstantByObjIds(objIds));
    }
}
